@@ -1,13 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1.3'
+__version__ = '0.1.5'
 
 from .conf import settings
 from .resource import Resource
 from .view import View
 from .form import Form
+from .request import Request
 from .response import Response
 from . import status
 from .filter import Filter
-from .auth import BasicAuth
+from .auth import Auth, BasicAuth
