@@ -6,13 +6,21 @@ from .exceptions import (
 )
 
 
-class BasicAuth(object):
+class Auth(object):
+    """The base class of Authentication."""
+
+    def check_auth(self, method, auth_params=None):
+        pass
+
+
+class BasicAuth(Auth):
     """Basic Authentication."""
 
     # inherent limit of the resource
     allowed_methods = (
         'GET_LIST', 'GET_ITEM',
-        'POST', 'PUT', 'PATCH', 'DELETE'
+        'POST', 'PUT', 'PATCH',
+        'DELETE_LIST', 'DELETE_ITEM'
     )
 
     def check_auth(self, method, auth_params=None):
@@ -21,14 +29,15 @@ class BasicAuth(object):
 
         auth_params = auth_params or {}
         if not self.authenticated(method, auth_params):
-            headers = {
-                'WWW-Authenticate': 'Basic realm:"resource"'
-            }
-            raise UnauthorizedError(headers=headers)
+            raise UnauthorizedError(headers=self.make_headers())
 
         if not self.authorized():
             raise ForbiddenError()
 
+    def make_headers(self):
+        """The response headers when authentication fails."""
+        return {'WWW-Authenticate': 'Basic realm:"resource"'}
+
     def authenticated(self, method, auth_params):
         """Authenticate the user with credentials in `auth_params`.
 
