@@ -3,6 +3,7 @@
 
 from __future__ import absolute_import
 
+import re
 import json
 import base64
 
@@ -118,13 +119,16 @@ def get_args(resource):
     uri = resource.uri.rstrip('/')
     if uri.startswith('/'):
         uri = uri[1:]
+    # change `uri` from Flask-style to Django-style
+    uri = re.sub(r'<(\w+)>', r'(?P<\1>\w+)', uri)
+
     endpoint = str(resource.name)
     view_cls = make_view(resource.view)
     return uri, endpoint, view_cls
 
 
 def url_rule(regex, view_cls, kwargs=None, methods=None):
-    methods = methods or ['GET', 'POST', 'PUT', 'DELETE']
+    methods = methods or ['GET', 'POST', 'PUT', 'PATCH', 'DELETE']
     methods = map(lambda m: m.lower(), methods)
 
     # set `http_method_names` on instance-level of `view_cls`
@@ -137,8 +141,8 @@ def url_rule(regex, view_cls, kwargs=None, methods=None):
 def add_resource(resource, pk='pk'):
     uri, _, view_cls = get_args(resource)
     urlpatterns = patterns('',
-        url_rule(r'^%s$' % normalize_uri(uri), view_cls, {pk: None},
-                 methods=['GET', 'POST']),
+        url_rule(r'^%s$' % normalize_uri(uri), view_cls,
+                 methods=['GET', 'POST', 'DELETE']),
         url_rule(r'^%s$' % normalize_uri('%s/(?P<pk>\w+)' % uri), view_cls,
                  methods=['GET', 'PUT', 'PATCH', 'DELETE'])
     )
@@ -148,7 +152,6 @@ def add_resource(resource, pk='pk'):
 def make_root(resource, pk='pk'):
     uri, _, view_cls = get_args(resource)
     urlpatterns = patterns('',
-        url_rule(r'^%s$' % normalize_uri(uri), view_cls, {pk: None},
-                 methods=['GET']),
+        url_rule(r'^%s$' % normalize_uri(uri), view_cls, methods=['GET'])
     )
     return urlpatterns
